SystemOrganization addCategory: #ConfigurationOfParasol!

Object subclass: #ConfigurationOfParasol
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfParasol'!

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfParasol class methodsFor: 'metacello tool support' stamp: 'KrisGybels 6/22/2012 17:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfParasol class methodsFor: 'loading' stamp: 'KrisGybels 7/4/2012 16:44'!
load

	"self load"

	<apiDocumentation>
	^(self project version: '1.0-baseline') load! !

!ConfigurationOfParasol class methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^self new project! !

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'JohanBrichau 2/21/2013 09:10'!
baseline: spec

	<version: '1.0-baseline'>
	
	spec for: #common do: [

		spec project: 'ZincHTTP'.

		spec project: 'Seaside30' with: [
			spec
				className: 'ConfigurationOfSeaside30';
				versionString: '3.0.6.4';
				operator: #>=;
				file: 'ConfigurationOfSeaside30';
				loads: #('Core');
				repository: 'http://www.squeaksource.com/MetacelloRepository'
		].

		spec
			blessing: #baseline;
			repository: 'http://ss3.gemstone.com/ss/Parasol';
			package: 'Parasol-Core' with: [
				spec requires: #('ZincHTTP')
			];
			package: 'Parasol-Tests' with: [
				spec requires: #('Parasol-Core' 'Seaside30')
			];
			package: 'Parasol-Convenience' with: [
				spec requires: #('Parasol-Core')
			];
			package: 'Parasol-Pharo' with: [
				spec requires: #('Parasol-Core')
			].
		
		spec
			group: 'default'
			with: #('Parasol-Core' 'Parasol-Pharo').
		spec
			group: 'tests'
			with: #('Parasol-Tests' 'Parasol-Pharo').
		spec
			group: 'dev'
			with: #('tests' 'Parasol-Convenience').
	].

	 spec for: #squeakCommon do: [
		spec project: 'ZincHTTP' overrides: [
			spec
				className: 'ConfigurationOfZincHTTPComponents';
				versionString: '1.7';
				operator: #>=;
				file: 'ConfigurationOfZincHTTPComponents';
				loads: 'Core';
				repository: 'http://www.squeaksource.com/ZincHTTPComponents'
		].
		
		spec project: 'Seaside30' with: [
			spec
				className: 'ConfigurationOfSeaside30';
				versionString: '3.0.6.4';
				operator: #>=;
				file: 'ConfigurationOfSeaside30';
				loads: #('Core' 'Seaside-Adaptors-Comanche');
				repository: 'http://www.squeaksource.com/MetacelloRepository'
		
		].
	
	spec
		for: #'gs2.4.x'
		do:[
			
			"Zinc HTTP"
			spec removeProject: 'ZincHTTP'.
			spec 
				baseline: 'ZincHTTP'
				with: 
					[ spec
						className: 'BaselineOfZinc';
						loads: 'Core';
						repository: 'github://glassdb/zinc:gemstone2.4/repository'].
			]
	]! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'KrisGybels 7/4/2012 16:18'!
development: spec

	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0-baseline'.
! !

!ConfigurationOfParasol methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !
